@@ -102,7 +102,7 @@ sub create_website_from_proto {
   my ($self, $home_dir, $module_name) = @_;
   
   unless (defined $home_dir) {
-    confess "Home directory must be specified\n";
+    confess "Home directory must be specifed\n";
   }
   
   if (-f $home_dir) {
@@ -157,16 +157,6 @@ sub create_website_from_proto {
     },
     $proto_dir
   );
-  
-  # git init repository directory
-  my @git_init_cmd_rep = ('git', 'init', $home_dir);
-  system(@git_init_cmd_rep) == 0
-    or confess "Can't execute command : @git_init_cmd_rep: $!";
-  
-  # git init public directory
-  my @git_init_cmd_public = ('git', 'init', "$home_dir/public");
-  system(@git_init_cmd_public) == 0
-    or confess "Can't execute command : @git_init_cmd_public: $!";
 }
 
 sub rel_file {
@@ -599,16 +589,12 @@ sub parse_description_from_first_p_tag {
   # Create description from first p tag
   if ($content =~ m|<\s?p\b[^>]*?>(.*?)<\s?/\s?p\s?>|s) {
     my $description = $1;
-    
     # remove tag
-    $description =~ s/<[^<]*?>//g;
+    $description =~ s/<.*?>//g;
     
     # trim space
     $description =~ s/^\s+//;
     $description =~ s/\s+$//;
-
-    # remove new lines
-    $description =~ s/\n//g;
     
     $data->{'description'} = $description;
   }
@@ -773,23 +759,8 @@ sub write_to_public_file {
   my $public_dir = dirname $public_file;
   mkpath $public_dir;
   
-  # Need update public file
-  my $is_need_update_public_file;
-  if (!-f $public_file) {
-    $is_need_update_public_file = 1;
-  }
-  else {
-    # Get original content
-    my $original_content = $self->slurp_file($public_file);
-    unless ($content eq $original_content) {
-      $is_need_update_public_file = 1;
-    }
-  }
-  
   # Write to public file
-  if ($is_need_update_public_file) {
-    $self->write_to_file($public_file, $content);
-  }
+  $self->write_to_file($public_file, $content);
 }
 
 1;
@@ -925,22 +896,15 @@ If module name is "Giblog::Command::new_foo" and the loading path is "lib/Giblog
 
 Module must be loaded before calling "create_website_from_proto". otherwise exception occur.
 
-The web site directry is initialized by git and C<public> direcotry is also initialized by git.
+If home directory is not specific, exception occur.
 
-  git init foo
-  git init foo/public 
-  
-If home directory is not specific, a exception occurs.
+If home directory already exists, exception occur.
 
-If home directory already exists, a exception occurs.
+If creating directory fail, exception occur.
 
-If creating directory fail, a exception occurs.
+If proto directory corresponding to module name is not specific, exception occur.
 
-If proto directory corresponding to module name is not specific, a exception occurs.
-
-If proto direcotry corresponding to module name is not found, a exception occurs.
-
-If git command is not found, a exception occurs.
+If proto direcotry corresponding to module name is not found, exception occur.
 
 =head2 copy_static_files_to_public
 
@@ -1470,5 +1434,3 @@ B<INPUT:>
 
   $data->{content}
   $data->{file}
-
-If the original content of the file is same as the new content of the file is same, this method don't write to public file. This means file time stamp is not be updated.
